==> 0.0.1.tar.gz: test/yao_odoo_provider_service_test.dart <==
import 'dart:async';

import 'package:flutter_test/flutter_test.dart';
import 'package:yao_core/yao_core.dart';
import 'package:yao_odoo_service/yao_odoo_service.dart';
import 'package:yao_odoo_provider_service/yao_odoo_provider_service.dart';

void main() {
  test('provider ...', () async {
    final app = Yao();
    app.inject(YaoOdooService(
        Connection(url: Url(Protocol.http, "localhost", 8069), db: 'test_01')));

    Future t() async {
      app.run();
    }

    await Future.wait([
      Future.any([
        app.wait(EitherType(YaoEvent.appReady)),
        app.wait(EitherType(YaoEvent.appError))
      ]),
      t()
    ]);

    await app.find<YaoOdooService>().connect(Credential("admin", "admin"));
    final userProvider = YaoOdooProviderService(User());
    final id = await userProvider.insert(User(login: "test2222", name: "test"));
    print("created : ${(await userProvider.read(id))!.toJson()}");
    await userProvider.update(User(id: id, name: "budi", login: "test1111"));
    print("updated & query : ${(await userProvider.query(where: [
          ['id', '=', id]
        ])).first.toJson()}");
    await userProvider.delete(id);
    print("deleted & read: ${(await userProvider.read(id)) == null}");
  });
}

class User implements IOdooModel {
  final int? id; //false
  final String? login; //false
  final String? name; //false

  User({this.id, this.login, this.name});
  factory User.fromJson(Map<String, dynamic> json) => _$UserFromJson(json);
  Map<String, dynamic> toJson() => _$UserToJson(this);

  @override
  User fromJson(Map<String, dynamic> json) {
    return User.fromJson(json);
  }

  @override
  int? getId() {
    return this.id;
  }

  @override
  String getTableName() => "res.users";

  @override
  Map<String, dynamic> toJsonWithReduce(
      bool Function(MapEntry<String, dynamic> p1) validate) {
    Map<String, dynamic> fields = this.toJson();
    Map<String, dynamic> tmp = {};
    for (final field in fields.entries) {
      if (validate(field) == false) {
        continue;
      }

      tmp.putIfAbsent(field.key, () => field.value);
    }
    return tmp;
  }

  @override
  Map<String, dynamic> toJsonWithoutNullAndId() {
    return toJsonWithReduce((MapEntry entry) {
      if (entry.value == null || entry.key == 'id') {
        return false;
      }
      return true;
    });
  }

  @override
  List<String> getColumns() {
    List<String> resp = [];
    final tmp = this.toJson();
    for (final entry in tmp.keys) {
      resp.add(entry);
    }
    return resp;
  }
}

User _$UserFromJson(Map<String, dynamic> json) {
  return User(
      id: json['id'] as int,
      login: json['login'] as String,
      name: json['name'] as String);
}

Map<String, dynamic> _$UserToJson(User instance) => <String, dynamic>{
      'id': instance.id,
      'login': instance.login,
      'name': instance.name
    };

==> 0.0.2.tar.gz: test/yao_odoo_provider_service_test.dart <==
import 'dart:async';

import 'package:flutter_test/flutter_test.dart';
import 'package:yao_core/yao_core.dart';
import 'package:yao_odoo_service/yao_odoo_service.dart';
import 'package:yao_odoo_provider_service/yao_odoo_provider_service.dart';

void main() {
  test('provider ...', () async {
    final app = Yao();
    app.inject(YaoOdooService(
        Connection(url: Url(Protocol.http, "localhost", 8069), db: 'test_01')));

    Future t() async {
      app.run();
    }

    await Future.wait([
      Future.any([
        app.wait(EitherType(YaoEvent.appReady)),
        app.wait(EitherType(YaoEvent.appError))
      ]),
      t()
    ]);

    // await app.find<YaoOdooService>().connect(Credential("admin", "admin"));
    // final userProvider = YaoOdooProviderService(User());
    // final id = await userProvider.insert(User(login: "test2222", name: "test"));
    // print("created : ${(await userProvider.read(id))!.toJson()}");
    // await userProvider.update(User(id: id, name: "budi", login: "test1111"));
    // print("updated & query : ${(await userProvider.query(where: [
    //       ['id', '=', id]
    //     ])).first.toJson()}");
    // await userProvider.delete(id);
    // print("deleted & read: ${(await userProvider.read(id)) == null}");
  });
}

class User implements IOdooModel {
  final int? id; //false
  final String? login; //false
  final String? name; //false

  User({this.id, this.login, this.name});
  factory User.fromJson(Map<String, dynamic> json) => _$UserFromJson(json);
  Map<String, dynamic> toJson() => _$UserToJson(this);

  @override
  User fromJson(Map<String, dynamic> json) {
    return User.fromJson(json);
  }

  @override
  int? getId() {
    return this.id;
  }

  @override
  String getTableName() => "res.users";

  @override
  Map<String, dynamic> toJsonWithReduce(
      bool Function(MapEntry<String, dynamic> p1) validate) {
    Map<String, dynamic> fields = this.toJson();
    Map<String, dynamic> tmp = {};
    for (final field in fields.entries) {
      if (validate(field) == false) {
        continue;
      }

      tmp.putIfAbsent(field.key, () => field.value);
    }
    return tmp;
  }

  @override
  Map<String, dynamic> toJsonWithoutNullAndId() {
    return toJsonWithReduce((MapEntry entry) {
      if (entry.value == null || entry.key == 'id') {
        return false;
      }
      return true;
    });
  }

  @override
  List<String> getColumns() {
    List<String> resp = [];
    final tmp = this.toJson();
    for (final entry in tmp.keys) {
      resp.add(entry);
    }
    return resp;
  }
}

User _$UserFromJson(Map<String, dynamic> json) {
  return User(
      id: json['id'] as int,
      login: json['login'] as String,
      name: json['name'] as String);
}

Map<String, dynamic> _$UserToJson(User instance) => <String, dynamic>{
      'id': instance.id,
      'login': instance.login,
      'name': instance.name
    };
